Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/mcp4728_simpletest.py
    :caption: examples/mcp4728_simpletest.py
    :linenos:

Vref Example
------------

Example showing the way to work with Vref

.. literalinclude:: ../examples/mcp4728_vref_example.py
    :caption: examples/examples/mcp4728_vref_example.py
    :linenos:

General Call Example
----------------------

Example showing the way to work with General Calls

.. literalinclude:: ../examples/mcp4728_generalcalltest.py
    :caption: examples/examples/mcp4728_generalcalltest.py
    :linenos:
